<!DOCTYPE TS><TS>
<context>
    <name>String::DayOfWeek</name>
    <message>
        <source>MON</source>
        <translation>PON</translation>
    </message>
    <message>
        <source>TUE</source>
        <translation>TOR</translation>
    </message>
    <message>
        <source>WED</source>
        <translation>SRE</translation>
    </message>
    <message>
        <source>THU</source>
        <translation>ČET</translation>
    </message>
    <message>
        <source>FRI</source>
        <translation>PET</translation>
    </message>
    <message>
        <source>SAT</source>
        <translation>SOB</translation>
    </message>
    <message>
        <source>SUN</source>
        <translation>NED</translation>
    </message>
</context>
<context>
    <name>String::WeatherType</name>
    <message>
        <source>Cloudy</source>
        <translation>Oblačno</translation>
    </message>
    <message>
        <source>Mostly Cloudy</source>
        <translation>Pretežno oblačno</translation>
    </message>
    <message>
        <source>Partly Cloudy</source>
        <translation>Deloma oblačno</translation>
    </message>
    <message>
        <source>Light Rain</source>
        <translation>Rahlo deževno</translation>
    </message>
    <message>
        <source>Showers</source>
        <translation>Plohe</translation>
    </message>
    <message>
        <source>Rain</source>
        <translation>Dež</translation>
    </message>
    <message>
        <source>AM Showers</source>
        <translation>Dop Plohe</translation>
    </message>
    <message>
        <source>Fog</source>
        <translation>Megla</translation>
    </message>
    <message>
        <source>Few Showers</source>
        <translation>Nekaj ploh</translation>
    </message>
    <message>
        <source>Mostly Sunny</source>
        <translation>Pretežno sončno</translation>
    </message>
    <message>
        <source>Sunny</source>
        <translation>Sončno</translation>
    </message>
    <message>
        <source>Scattered Flurries</source>
        <translation>Občasni vetrovni sunki</translation>
    </message>
    <message>
        <source>AM Clouds/PM Sun</source>
        <translation>Dop Oblačno/Pop Sončno</translation>
    </message>
    <message>
        <source>Isolated T-Storms</source>
        <translation>Posamezni Tornadi</translation>
    </message>
    <message>
        <source>Scattered Thunderstorms</source>
        <translation>Občasne nevihte</translation>
    </message>
    <message>
        <source>PM Showers</source>
        <translation>Pop Plohe</translation>
    </message>
    <message>
        <source>PM Showers/Wind</source>
        <translation>Pop Plohe/Veter</translation>
    </message>
    <message>
        <source>Rain/Snow Showers</source>
        <translation>Dež/Snežne plohe</translation>
    </message>
    <message>
        <source>Few Snow Showers</source>
        <translation>Nekaj Snežnih ploh</translation>
    </message>
    <message>
        <source>Cloudy/Wind</source>
        <translation>Oblačno/Veter</translation>
    </message>
    <message>
        <source>Flurries/Wind</source>
        <translation>Vetrovni sunki/Veter</translation>
    </message>
    <message>
        <source>Mostly Cloudy/Windy</source>
        <translation>Pretežno oblačno/Vetrovno</translation>
    </message>
    <message>
        <source>Rain/Thunder</source>
        <translation>Dež/Grmljenje</translation>
    </message>
    <message>
        <source>Partly Cloudy/Windy</source>
        <translation>Deloma oblačno/Vetrovno</translation>
    </message>
    <message>
        <source>AM Rain/Snow Showers</source>
        <translation>Dop Dež/Snežne plohe</translation>
    </message>
    <message>
        <source>Light Rain/Wind</source>
        <translation>Rahlo deževno/Veter</translation>
    </message>
    <message>
        <source>Showers/Wind</source>
        <translation>Plohe/Veter</translation>
    </message>
    <message>
        <source>Mostly Sunny/Wind</source>
        <translation>Pretežno sončno/Vetrovno</translation>
    </message>
    <message>
        <source>Flurries</source>
        <translation>Vetrovni sunki</translation>
    </message>
    <message>
        <source>Rain/Wind</source>
        <translation>Dež/Veter</translation>
    </message>
    <message>
        <source>Sct Flurries/Wind</source>
        <translation>Občasni vetrovni sunki/Veter</translation>
    </message>
    <message>
        <source>Sct Strong Storms</source>
        <translation>Občasne močne nevihte</translation>
    </message>
    <message>
        <source>PM T-Storms</source>
        <translation>Pop Tornadi</translation>
    </message>
    <message>
        <source>Thunderstorms</source>
        <translation>Nevihte</translation>
    </message>
    <message>
        <source>Sunny/Windy</source>
        <translation>Sončno/Vetrovno</translation>
    </message>
    <message>
        <source>AM Thunderstorms</source>
        <translation>Dop Nevihte</translation>
    </message>
    <message>
        <source>AM Rain</source>
        <translation>Dop Dež</translation>
    </message>
    <message>
        <source>Iso T-Storms/Wind</source>
        <translation>Posamezni Tornadi/Veter</translation>
    </message>
    <message>
        <source>Rain/Snow</source>
        <translation>Dež/Sneg</translation>
    </message>
    <message>
        <source>Sct T-Storms/Wind</source>
        <translation>Občasni Tornadi/Veter</translation>
    </message>
    <message>
        <source>AM Showers/Wind</source>
        <translation>Dop Plohe/Veter</translation>
    </message>
    <message>
        <source>Sct Snow Showers</source>
        <translation>Občasne snežne plohe</translation>
    </message>
    <message>
        <source>Snow to Ice/Wind</source>
        <translation>Sneg v Led/Veter</translation>
    </message>
    <message>
        <source>Snow to Rain</source>
        <translation>Sneg v Dež</translation>
    </message>
    <message>
        <source>AM Light Rain</source>
        <translation>Dop rahlo deževno</translation>
    </message>
    <message>
        <source>PM Light Rain</source>
        <translation>Pop rahlo deževno</translation>
    </message>
    <message>
        <source>PM Rain</source>
        <translation>Pop Dež</translation>
    </message>
    <message>
        <source>Snow Showers</source>
        <translation>Snežne plohe</translation>
    </message>
    <message>
        <source>Rain to Snow</source>
        <translation>Dež v Sneg</translation>
    </message>
    <message>
        <source>PM Rain/Snow</source>
        <translation>Pop Dež/Sneg</translation>
    </message>
    <message>
        <source>Few Showers/Wind</source>
        <translation>Nekaj ploh/Veter</translation>
    </message>
    <message>
        <source>Snow/Wind</source>
        <translation>Sneg/Veter</translation>
    </message>
    <message>
        <source>PM Rain/Snow Showers</source>
        <translation>Pop Dež/Snežne plohe</translation>
    </message>
    <message>
        <source>PM Rain/Snow/Wind</source>
        <translation>Dop Dež/Veter/Sneg</translation>
    </message>
    <message>
        <source>Rain/Snow Showers/Wind</source>
        <translation>Dež/Snežne plohe/Veter</translation>
    </message>
    <message>
        <source>Rain/Snow/Wind</source>
        <translation>Dež/Veter/Sneg</translation>
    </message>
    <message>
        <source>Light Snow</source>
        <translation>Rahlo sneženje</translation>
    </message>
    <message>
        <source>PM Snow</source>
        <translation>Pop Sneg</translation>
    </message>
    <message>
        <source>Few Snow Showers/Wind</source>
        <translation>Nekaj Snežnih ploh/Veter</translation>
    </message>
    <message>
        <source>Light Snow/Wind</source>
        <translation>Rahlo sneženje/Veter</translation>
    </message>
    <message>
        <source>Wintry Mix</source>
        <translation>Vetrovno</translation>
    </message>
    <message>
        <source>AM Wintry Mix</source>
        <translation>Dop Vetrovno</translation>
    </message>
    <message>
        <source>Hvy Rain/Freezing Rain</source>
        <translation>Težko deževje/Zmrzljiv dež</translation>
    </message>
    <message>
        <source>AM Light Snow</source>
        <translation>Dop rahlo sneženje</translation>
    </message>
    <message>
        <source>Rain/Freezing Rain</source>
        <translation>Dež/Zmrzljiv dež</translation>
    </message>
    <message>
        <source>T-Storms/Wind</source>
        <translation>Tornadi/Veter</translation>
    </message>
    <message>
        <source>Sprinkles</source>
        <translation>Pršenje</translation>
    </message>
    <message>
        <source>AM Snow Showers</source>
        <translation>Dop Snežne plohe</translation>
    </message>
    <message>
        <source>AM Clouds/PM Sun/Wind</source>
        <translation>Dop Oblačno/Pop Sončno/Veter</translation>
    </message>
    <message>
        <source>AM Rain/Snow/Wind</source>
        <translation>Dop Dež/Veter/Sneg</translation>
    </message>
    <message>
        <source>Rain to Snow/Wind</source>
        <translation>Dež v Sneg/Veter</translation>
    </message>
    <message>
        <source>Snow to Wintry Mix</source>
        <translation>Sneg v Vetrovno</translation>
    </message>
    <message>
        <source>PM Snow Showers/Wind</source>
        <translation>Pop Snežne plohe/Veter</translation>
    </message>
    <message>
        <source>Snow and Ice to Rain</source>
        <translation>Sneg in Led v Dež</translation>
    </message>
    <message>
        <source>Heavy Rain</source>
        <translation>Težko deževje</translation>
    </message>
    <message>
        <source>AM Rain/Ice</source>
        <translation>Dop Dež/Led</translation>
    </message>
    <message>
        <source>AM Snow Showers/Wind</source>
        <translation>Dop Snežne plohe/Veter</translation>
    </message>
    <message>
        <source>AM Light Snow/Wind</source>
        <translation>Dop rahlo sneženje/Veter</translation>
    </message>
    <message>
        <source>PM Light Rain/Wind</source>
        <translation>Pop rahlo deževno/Veter</translation>
    </message>
    <message>
        <source>AM Light Wintry Mix</source>
        <translation>Dop rahlo vetrovno</translation>
    </message>
    <message>
        <source>PM Light Snow/Wind</source>
        <translation>Pop rahlo sneženje/Veter</translation>
    </message>
    <message>
        <source>Heavy Rain/Wind</source>
        <translation>Težko deževje/Veter</translation>
    </message>
    <message>
        <source>PM Snow Shower</source>
        <translation>Pop Snežne plohe</translation>
    </message>
    <message>
        <source>Snow to Rain/Wind</source>
        <translation>Sneg v Dež/Veter</translation>
    </message>
    <message>
        <source>PM Light Rain/Ice</source>
        <translation>Pop rahlo deževno/Led</translation>
    </message>
    <message>
        <source>AM Snow</source>
        <translation>Dop Sneg</translation>
    </message>
    <message>
        <source>Snow to Ice</source>
        <translation>Sneg v Led</translation>
    </message>
    <message>
        <source>Wintry Mix/Wind</source>
        <translation>Vetrovno/Veter</translation>
    </message>
    <message>
        <source>PM Light Snow</source>
        <translation>Pop rahlo sneženje</translation>
    </message>
    <message>
        <source>AM Drizzle</source>
        <translation>Dop Spremenljivo</translation>
    </message>
    <message>
        <source>Strong Storms/Wind</source>
        <translation>Močne nevihte/Veter</translation>
    </message>
    <message>
        <source>PM Drizzle</source>
        <translation>Pop Spremenljivo</translation>
    </message>
    <message>
        <source>Drizzle</source>
        <translation>Vetrovno</translation>
    </message>
    <message>
        <source>AM Light Rain/Wind</source>
        <translation>Dop rahlo deževno/Veter</translation>
    </message>
    <message>
        <source>AM Rain/Wind</source>
        <translation>Dop Dež/Veter</translation>
    </message>
    <message>
        <source>Wintry Mix to Snow</source>
        <translation>Vetrovno v Sneg</translation>
    </message>
    <message>
        <source>Snow Showers/Windy</source>
        <translation>Snežne plohe/Veter</translation>
    </message>
    <message>
        <source>Light Rain Shower</source>
        <translation>Raheo deževne plohe</translation>
    </message>
    <message>
        <source>Light Rain with Thunder</source>
        <translation>Rahlo deževno z grmenjem</translation>
    </message>
    <message>
        <source>Light Drizzle</source>
        <translation>Rahlo vetrovno</translation>
    </message>
    <message>
        <source>Mist</source>
        <translation>Megla</translation>
    </message>
    <message>
        <source>Smoke</source>
        <translation>Sopara</translation>
    </message>
    <message>
        <source>Haze</source>
        <translation>Nejasno</translation>
    </message>
    <message>
        <source>Light Snow Shower</source>
        <translation>Rahle snežne plohe</translation>
    </message>
    <message>
        <source>Light Snow Shower/ Windy</source>
        <translation>Rahle snežne plohe/Vetrovno</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Jasno</translation>
    </message>
    <message>
        <source>A Few Clouds</source>
        <translation>Nekaj oblačkov</translation>
    </message>
    <message>
        <source>Fair</source>
        <translation>Jasno</translation>
    </message>
</context>
<context>
    <name>String::WindDirection</name>
    <message>
        <source>N</source>
        <translation>S</translation>
    </message>
    <message>
        <source>NNE</source>
        <translation>SSE</translation>
    </message>
    <message>
        <source>NE</source>
        <translation>SV</translation>
    </message>
    <message>
        <source>ENE</source>
        <translation>VSV</translation>
    </message>
    <message>
        <source>E</source>
        <translation>V</translation>
    </message>
    <message>
        <source>ESE</source>
        <translation>VJV</translation>
    </message>
    <message>
        <source>SE</source>
        <translation>JV</translation>
    </message>
    <message>
        <source>SSE</source>
        <translation>JJV</translation>
    </message>
    <message>
        <source>S</source>
        <translation>J</translation>
    </message>
    <message>
        <source>SSW</source>
        <translation>JJZ</translation>
    </message>
    <message>
        <source>SW</source>
        <translation>JZ</translation>
    </message>
    <message>
        <source>WSW</source>
        <translation>ZJZ</translation>
    </message>
    <message>
        <source>W</source>
        <translation>Z</translation>
    </message>
    <message>
        <source>WNW</source>
        <translation>ZSZ</translation>
    </message>
    <message>
        <source>NW</source>
        <translation>SZ</translation>
    </message>
    <message>
        <source>NNW</source>
        <translation>SSZ</translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>loading...</source>
        <translation>nalagam...</translation>
    </message>
    <message>
        <source>[ retrieving weather data ... ]</source>
        <translation>[ sprejemanje vremenskih podatkov ... ]</translation>
    </message>
    <message>
        <source>current conditions</source>
        <translation>trenutni pogoji</translation>
    </message>
    <message>
        <source>Humidity</source>
        <translation>Vlažnost</translation>
    </message>
    <message>
        <source>Pressure</source>
        <translation>Pritisk</translation>
    </message>
    <message>
        <source>Wind</source>
        <translation>Veter</translation>
    </message>
    <message>
        <source>Visibility</source>
        <translation>Vidljivost</translation>
    </message>
    <message>
        <source>Wind Chill</source>
        <translation>Temperatura vetra</translation>
    </message>
    <message>
        <source>UV Index</source>
        <translation>UV Indeks</translation>
    </message>
    <message>
        <source>extended forecast</source>
        <translation>razširjena napoved</translation>
    </message>
    <message>
        <source>LO</source>
        <translation>NIZKA</translation>
    </message>
    <message>
        <source>HI</source>
        <translation>VISOKA</translation>
    </message>
    <message>
        <source>today&apos;s forecast</source>
        <translation>Današnja napoved</translation>
    </message>
    <message>
        <source>tomorrow&apos;s outlook</source>
        <translation>Jutrišnji pregled</translation>
    </message>
    <message>
        <source>Forecast for</source>
        <translation>Napoved za</translation>
    </message>
    <message>
        <source>doppler radar</source>
        <translation>dopplerjev oddjanik</translation>
    </message>
    <message>
        <source>Map Unavailable</source>
        <translation>Mapa ni na voljo</translation>
    </message>
    <message>
        <source>RAIN</source>
        <translation>DEŽ</translation>
    </message>
    <message>
        <source>MIX/ICE</source>
        <translation>MEŠANO/LED</translation>
    </message>
    <message>
        <source>SNOW</source>
        <translation>SNEG</translation>
    </message>
    <message>
        <source>LIGHT</source>
        <translation>RAHLO</translation>
    </message>
    <message>
        <source>HEAVY</source>
        <translation>TEŽKO</translation>
    </message>
    <message>
        <source>Enter Zip Code</source>
        <translation>Vnesite poštno številko</translation>
    </message>
    <message>
        <source>weather setup</source>
        <translation>vremenske nastavitve</translation>
    </message>
    <message>
        <source>To save, press &apos;i&apos; - to cancel, hit escape</source>
        <translation>Za shranitev, pritisnite &apos;i&apos; - za preklic pa Esc</translation>
    </message>
    <message>
        <source>COLD</source>
        <translation>MRZLO</translation>
    </message>
    <message>
        <source>COLDEST</source>
        <translation>FULL MRZLO</translation>
    </message>
    <message>
        <source>CLOUD TEMPERATURE</source>
        <translation>TEMPERATURA ZRAKA</translation>
    </message>
</context>
<context>
    <name>Weather</name>
    <message>
        <source>doppler radar</source>
        <translation type="obsolete">dopplerjev oddjanik</translation>
    </message>
    <message>
        <source>satellite image</source>
        <translation type="obsolete">satelitska slika</translation>
    </message>
    <message>
        <source> is invalid)</source>
        <translation>je napačna)</translation>
    </message>
    <message>
        <source>   No Location Set, Please read the README</source>
        <translation>   Ni nastavljenega mesta, prosim preberite README</translation>
    </message>
    <message>
        <source> - PAUSED -</source>
        <translation>- PAVZIRANO -</translation>
    </message>
    <message>
        <source>Configuring MythWeather...</source>
        <translation>Nastavljam MythWeather...</translation>
    </message>
    <message>
        <source>Use the right arrow key to select unit conversion...</source>
        <translation>Uporabite desno smerno tipko za izbiro pretvornika merskih enot...</translation>
    </message>
    <message>
        <source>Weather Units</source>
        <translation>Vremenske enote</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Mesto</translation>
    </message>
    <message>
        <source>Aggressiveness</source>
        <translation>Agresivnost</translation>
    </message>
    <message>
        <source>Imperial (Fahrenheit, in, etc)</source>
        <translation>Imperial (Fahrenheit, v, ipd.)</translation>
    </message>
    <message>
        <source>Metric (Celsius, kPa, etc)</source>
        <translation>Metrični (Celzije, kPa, ipd.)</translation>
    </message>
    <message>
        <source>Configuration Saved...</source>
        <translation>Nastavitve shranjene...</translation>
    </message>
    <message>
        <source>Retrieving weather data...</source>
        <translation>Sprejemnje vremenskih podatkov ...</translation>
    </message>
    <message>
        <source>Use the right arrow key to select your location...</source>
        <translation>Uporabite desno smerno tipko za izbiro vaše lokacije...</translation>
    </message>
    <message>
        <source>Use the right arrow key to select the aggressiveness level...</source>
        <translation>Uporabite desno smerno tipko za nastavitev nivoja agresivnosti...</translation>
    </message>
    <message>
        <source> 1  High Speed Connection</source>
        <translation>1  Povezava z visoko hitrostjo</translation>
    </message>
    <message>
        <source> 8  Medium Speed Connection</source>
        <translation>8  Povezava s srednjo hitrostjo</translation>
    </message>
    <message>
        <source> 15 Low Speed Connection</source>
        <translation>15 Povezava z nizko hitrostjo</translation>
    </message>
    <message>
        <source>Obtaining initial weather data...</source>
        <translation>Pridobivam začetne vremenske podatke...</translation>
    </message>
    <message>
        <source>Updating weather data...</source>
        <translation>Nadgrajevanje vremenskih podatkov ...</translation>
    </message>
    <message>
        <source>Calm</source>
        <translation>Mrzlo</translation>
    </message>
    <message>
        <source> at </source>
        <translation> pri </translation>
    </message>
    <message>
        <source>Unlimited</source>
        <translation>Neomejena</translation>
    </message>
    <message>
        <source> F</source>
        <translation>F</translation>
    </message>
    <message>
        <source> C</source>
        <translation>C</translation>
    </message>
    <message>
        <source> (minimal)</source>
        <translation>(minimalno)</translation>
    </message>
    <message>
        <source> (moderate)</source>
        <translation>(srednje)</translation>
    </message>
    <message>
        <source> (high)</source>
        <translation>(visok)</translation>
    </message>
    <message>
        <source> (extreme)</source>
        <translation>(ekstremno)</translation>
    </message>
    <message>
        <source>Today a high of </source>
        <translation>Danes bo najvišja temperatura </translation>
    </message>
    <message>
        <source> and a low of </source>
        <translation>, najnižja pa  </translation>
    </message>
    <message>
        <source>. Currently there is a humidity of </source>
        <translation>. Trenutna vlažnost je  </translation>
    </message>
    <message>
        <source>% and the winds are</source>
        <translation>%. Veter piha</translation>
    </message>
    <message>
        <source> calm.</source>
        <translation>mrzlo.</translation>
    </message>
    <message>
        <source> coming in at </source>
        <translation> z močjo </translation>
    </message>
    <message>
        <source> mph from the </source>
        <translation>mph iz </translation>
    </message>
    <message>
        <source> Km/h from the </source>
        <translation>Km/h iz  </translation>
    </message>
    <message>
        <source> Visibility will be unlimited for today.</source>
        <translation>Vidljivost bo danes visoka.</translation>
    </message>
    <message>
        <source> Visibility conditions are unknown.</source>
        <translation>Pogoji o vidljivosti niso znani.</translation>
    </message>
    <message>
        <source> There will be a visibility of </source>
        <translation>Vidljivost bo</translation>
    </message>
    <message>
        <source> miles.</source>
        <translation>milje.</translation>
    </message>
    <message>
        <source> km.</source>
        <translation>km.</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Nedelja</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Ponedeljek</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Torek</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Sreda</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Četrtek</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Petek</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Sobota</translation>
    </message>
    <message>
        <source>Date Error</source>
        <translation>Napaka datuma</translation>
    </message>
    <message>
        <source>Tomorrow expect a high of </source>
        <translation>Jutri se pričakuje visoka</translation>
    </message>
    <message>
        <source>.</source>
        <translation>.</translation>
    </message>
    <message>
        <source>Expected conditions: </source>
        <translation>Pričakovani pogoji:</translation>
    </message>
    <message>
        <source>Weather data from: </source>
        <translation>Vremenski podatki:  </translation>
    </message>
    <message>
        <source>Updating...</source>
        <translation>Nadgrajevanje...</translation>
    </message>
    <message>
        <source> (Not All Information Available)</source>
        <translation>(Ni na voljo vseh informacij)</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Neznano</translation>
    </message>
    <message>
        <source>*** Invalid Area ID or Server Error ***</source>
        <translation>*** Napačna oznaka področja ali napaka serverja ***</translation>
    </message>
    <message>
        <source>Myth was unable to retrieve your weather data within the time allowed (%1 seconds).
Press OK to try again with a larger timeout value. Press Cancel to try again without animated radar maps.</source>
        <translation>Myth ni mogel, znotraj časovnega intervala (%1 sekund), sprejeti vremenskih podatkov.
Pritisnite VREDU ali poizkušajte z daljšim časovnim intervalom. Pritisnite PREKLIČI za poizkus brez radarskih posnetkov.</translation>
    </message>
    <message>
        <source>Myth was unable to retrieve your weather data within the time allowed (%1 seconds).
Press OK to try again with a larger timeout value. Press Cancel to abort.</source>
        <translation>Myth ni mogel, znotraj časovnega intervala (%1 sekund), sprejeti vremenskih podatkov.
Pritisnite VREDU ali poizkušajte z daljšim časovnim intervalom. Pritisnite PREKLIČI za preklic.</translation>
    </message>
</context>
</TS>
